@@ -1,5 +1,5 @@
 /*
- * bibtexin.c
+ * bibtexdirectin.c
  *
  * Copyright (c) Georgi N. Boshnakov 2021
  *
@@ -25,6 +25,10 @@
 #include "bibformats.h"
 #include "generic.h"
 
+extern int rdpack_patch_for_i_acute_variant;
+extern int convert_latex_escapes_only; // Georgi
+extern int export_tex_chars_only;      // Georgi
+
 #include "R.h"
 
 static slist find    = { 0, 0, 0, NULL };
@@ -92,6 +96,10 @@ void bibdirectin_more_cleanf()
   //       note that 'find' and 'replace' work in tandem, so both need to be cleared.
   slist_free( &find );
   slist_free( &replace );
+  convert_latex_escapes_only = 0;
+  export_tex_chars_only = 0;
+  rdpack_patch_for_i_acute_variant = 0;
+
 }
 
 
@@ -771,53 +779,52 @@ bibtex_matches_asis_or_corps( fields *bibin, int m, param *pm, int *match )
 static int
 bibtex_person_tokenize( fields *bibin, int m, param *pm, slist *tokens )
 {
-	int i, ok, status;
-	str *s;
-
+     int i, ok, status;
+     str *s;
 	
-	status = latex_tokenize( tokens, fields_value( bibin, m, FIELDS_STRP ) );
-	if ( status!=BIBL_OK ) return status;
+     status = latex_tokenize( tokens, fields_value( bibin, m, FIELDS_STRP ) );
+     if ( status!=BIBL_OK ) return status;
 
-// REprintf("\nbibtex_person_tokenize: person!\n");
-//  REprintf("number of tokens: %d\n", tokens->n);
-// 		for ( i=0; i<tokens->n; ++i )
-// 			REprintf( "%s\n", slist_cstr( tokens, i ) );
-// REprintf("\nbibtex_person_tokenize: person! --------------\n");
+     // REprintf("\nbibtex_person_tokenize: person!\n");
+     //  REprintf("number of tokens: %d\n", tokens->n);
+     // 		for ( i=0; i<tokens->n; ++i )
+     // 			REprintf( "%s\n", slist_cstr( tokens, i ) );
+     // REprintf("\nbibtex_person_tokenize: person! --------------\n");
 
-	for ( i=0; i<tokens->n; ++i ) {
+     for ( i=0; i<tokens->n; ++i ) {
 
-		s = slist_str( tokens, i );
+	  s = slist_str( tokens, i );
 
-		// Georgi: removing since changes latex characters to unicode
-		//         in names, see comments in bibtexin_cleanref() (in bibtexin.c)
-		//    TODO: check if this causes bad side effects, ideally correct
-		//
-		// Reinstating this, bad side effects
-		status = bibtex_cleanvalue( s );
-		if ( status!=BIBL_OK ) return status;
+	  // Georgi: removing since changes latex characters to unicode
+	  //         in names, see comments in bibtexin_cleanref() (in bibtexin.c)
+	  //    TODO: check if this causes bad side effects, ideally correct
+	  //
+	  // Reinstating this, bad side effects
+	  status = bibtex_cleanvalue( s );
+	  if ( status!=BIBL_OK ) return status;
 
-		// !!! Georgi: conversion is here!
-		// !!!
-		// REprintf("\ns before str_convert: %s\n", s->data);
-		// ok = str_convert( s, pm->charsetin,  1, pm->utf8in,  pm->xmlin,
-		  ok = str_convert( s, pm->charsetin,  pm->latexin, pm->utf8in,  pm->xmlin,
-				    // Georgi: change arg. latexout to 1
-				    // TODO: make it argument to this function?
-				    //       it should depend on --no-latex
-				    // v1.3 - restoring latexout to 0
-				    pm->charsetout, 0, pm->utf8out, pm->xmlout );
-		  // REprintf("s after str_convert: %s\n", s->data);
-		if ( !ok ) return BIBL_ERR_MEMERR;
+	  // !!! Georgi: conversion is here!
+	  // !!!
+	  // REprintf("\ns before str_convert: %s\n", s->data);
+	  // ok = str_convert( s, pm->charsetin,  1, pm->utf8in,  pm->xmlin,
+	  ok = str_convert( s, pm->charsetin,  pm->latexin, pm->utf8in,  pm->xmlin,
+			    // Georgi: change arg. latexout to 1
+			    // TODO: make it argument to this function?
+			    //       it should depend on --no-latex
+			    // v1.3 - restoring latexout to 0
+			    pm->charsetout, 0, pm->utf8out, pm->xmlout );
+	  // REprintf("s after str_convert: %s\n", s->data);
+	  if ( !ok ) return BIBL_ERR_MEMERR;
 
-	}
+     }
 
-// REprintf("\nbibtex_person_tokenize: person!\n");
-//  REprintf("number of tokens: %d\n", tokens->n);
-// 		for ( i=0; i<tokens->n; ++i )
-// 			REprintf( "%s\n", slist_cstr( tokens, i ) );
-// REprintf("\nbibtex_person_tokenize: person! --------------\n");
+     // REprintf("\nbibtex_person_tokenize: person!\n");
+     //  REprintf("number of tokens: %d\n", tokens->n);
+     // 		for ( i=0; i<tokens->n; ++i )
+     // 			REprintf( "%s\n", slist_cstr( tokens, i ) );
+     // REprintf("\nbibtex_person_tokenize: person! --------------\n");
 	
-	return BIBL_OK;
+     return BIBL_OK;
 }
 
 /* We need to:
@@ -875,7 +882,7 @@ bibtexdirectin_person( fields *bibin, int m, param *pm )
 {
 	int status, match = 0;
 	slist tokens;
- // REprintf("\nbibtexdirectin_person!\n");
+	// REprintf("\nbibtexdirectin_person!\n");
 
 	status = bibtex_matches_asis_or_corps( bibin, m, pm, &match );
 	if ( status!=BIBL_OK || match==1 ) return status;
@@ -913,124 +920,115 @@ out:
 static int
 bibtexdirectin_cleanref( fields *bibin, param *pm )
 {
-	int i, n, fstatus, status = BIBL_OK;
-	str *tag, *value;
-	intlist toremove;
+     int i, n, fstatus, status = BIBL_OK;
+     str *tag, *value;
+     intlist toremove;
 
-	intlist_init( &toremove );
+     intlist_init( &toremove );
 
-	n = fields_num( bibin );
+     n = fields_num( bibin );
 
-	  // REprintf("\nbibtexdirectin_cleanref (start): n = %d\n" , n);
-	  // for(i = 0; i < n; i++) {
-	  //   REprintf("i = %d, value = %s\n", i, (bibin->value[i]).data);
-	  // }
+     // REprintf("\nbibtexdirectin_cleanref (start): n = %d\n" , n);
+     // for(i = 0; i < n; i++) {
+     //   REprintf("i = %d, value = %s\n", i, (bibin->value[i]).data);
+     // }
 	  
 
  
-	for ( i=0; i<n; ++i ) {
+     for ( i=0; i<n; ++i ) {
 
-		tag = fields_tag( bibin, i, FIELDS_STRP_NOUSE );
-		// REprintf("\nbibtexdirectin_cleanref: tag = %s", tag->data);
-		if ( is_url_tag( tag ) ) continue; /* protect url from parsing */
+	  tag = fields_tag( bibin, i, FIELDS_STRP_NOUSE );
+	  // REprintf("\nbibtexdirectin_cleanref: tag = %s", tag->data);
+	  if ( is_url_tag( tag ) ) continue; /* protect url from parsing */
 
-		/* Georgi:  protecting names, otherwise havoc ensues if the input is 
-                            in a different encoding; 
-                       TODO: test side effects of doing this.
-		   delay names from undergoing any parsing */
-		/* 2020-09-26: but names need parsing since there may be more than one!
-                       Commenting out to process properly names fields
+	  /* Georgi:  protecting names, otherwise havoc ensues if the input is 
+	     in a different encoding; 
+	     TODO: test side effects of doing this.
+	     delay names from undergoing any parsing */
+	  /* 2020-09-26: but names need parsing since there may be more than one!
+	     Commenting out to process properly names fields
 
-                       TODO: return to this and check again!
-                            I commented this out because of encodings - do tests!
-                       Amendment: run the nex two lines  but only if tag is not names tag
-                        (actually, moved them to the else part)
-		 */
-		// if ( is_name_tag( tag ) ) return BIBL_OK;
-		// if ( !is_name_tag( tag ) ){
-		value = fields_value( bibin, i, FIELDS_STRP_NOUSE );
-		if ( str_is_empty( value ) ) continue;
+	     TODO: return to this and check again!
+	     I commented this out because of encodings - do tests!
+	     Amendment: run the nex two lines  but only if tag is not names tag
+	     (actually, moved them to the else part)
+	  */
+	  // if ( is_name_tag( tag ) ) return BIBL_OK;
+	  // if ( !is_name_tag( tag ) ){
+	  value = fields_value( bibin, i, FIELDS_STRP_NOUSE );
+	  if ( str_is_empty( value ) ) continue;
 
-		// }
-		if ( is_name_tag( tag ) ) {
-			status = bibtexdirectin_person( bibin, i, pm );
+	  // }
+
+	  if(convert_latex_escapes_only) { // convert
+	       str_convert( value,
+			    // pm->charsetin,  pm->latexin,  pm->utf8in,  pm->xmlin,
+			    pm->charsetin,  1,  pm->utf8in,  pm->xmlin,
+			    // pm->charsetout, pm->latexout, pm->utf8out, pm->xmlout );
+			    pm->charsetout, 0, pm->utf8out, pm->xmlout );
+	  }
+	
+	  if(rdpack_patch_for_i_acute_variant) {
+	       str_findreplace(value, "\\'i", "\\'\\i");
+	  }
+
+	  if ( is_name_tag( tag ) ) {
+	       status = bibtexdirectin_person( bibin, i, pm );
 						
-// REprintf("\tbefore: i = %d, ", i);
-// REprintf("value = %s\n", (bibin->value[i]).data);
-// REprintf("\tafter:  newpos = %d, ", fields_num( bibin ) - 1);
-// REprintf("value = %s\n", (bibin->value[fields_num( bibin ) - 1]).data);
+	       // REprintf("\tbefore: i = %d, ", i);
+	       // REprintf("value = %s\n", (bibin->value[i]).data);
+	       // REprintf("\tafter:  newpos = %d, ", fields_num( bibin ) - 1);
+	       // REprintf("value = %s\n", (bibin->value[fields_num( bibin ) - 1]).data);
  
-			if ( status!=BIBL_OK ) goto out;
+	       if ( status!=BIBL_OK ) goto out;
 
-			fstatus = intlist_add( &toremove, i );
-			if ( fstatus!=INTLIST_OK ) { status = BIBL_ERR_MEMERR; goto out; }
-// REprintf("nout = %d\n" , fields_num( bibin ));
-                        // goto out;
-		}
-		// else {
-		//   // Georgi (2021-10-10) - this 'else' branch had been commented out;
-		//   //      start making it work;                 
-		//   // REprintf("i = %d, value = %s\n", i, (bibin->value[i]).data);
-		//   
-		//   // value = fields_value( bibin, i, FIELDS_STRP_NOUSE );
-		//   // if ( str_is_empty( value ) ) continue;
-		//  
-		//   // Georgi: bibtex_cleanvalue() drops $, {, }, for now just skip it
-		//   //   TODO: fix bibtex_cleanvalue() to not do that when not necessary 
-		//   // REprintf("i = %d, value = %s\n", i, value->data);
-		//   //     status = bibtex_cleanvalue( value );
-		//   // TODO: this should be conditional on a new value for texChars in readBib, requesting
-		//   //       conversion to Unicode but only for latex escape characters.
-		//   //
-		//   // name_fix_latex_escapes is just to get things going. It assumes that
-		//   //   there are only latex escape characters and no other commands. This is
-		//   //   fine for persons' names but not for toher fields.
-		//   //
-		//   // TODO: Also, probably should not process tag's like URL here (maybe additional else-if's)
-		//   // TODO: base other_fix_latex_escapes on name_fix_latex_escapes
-		//   //       However, this will not be successful. Need to be able to work
-		//   //       with the parsed late tree and only tuch stuff outside maths mode
-		//   //   No, this won't work; need proper look at the latex parse tree.
-		//   // status = other_fix_latex_escapes( value );
-		// 
-		//   // REprintf("i = %d, value = %s\n", i, (bibin->value[i]).data);
-		//   // if ( status!=BIBL_OK ) goto out;
-		// }
+	       fstatus = intlist_add( &toremove, i );
+	       if ( fstatus!=INTLIST_OK ) { status = BIBL_ERR_MEMERR; goto out; }
+	       // REprintf("nout = %d\n" , fields_num( bibin ));
+	       // goto out;
+	  }
+	  // else {
+	  //   status = bibtex_cleanvalue( value );
+	  //   if ( status!=BIBL_OK ) goto out;
+	  //   
+	  //   REprintf("i = %d, value = %s\n", i, (bibin->value[i]).data);
+	  //   
+	  // }
 
-	}
+     }
 
 
-	// int nout = fields_num( bibin );
-	// if(nout > n) {
-	//   REprintf("\nbibtexdirectin_cleanref (2): nout = %d\n" , nout);
-	//   for(i = 0; i < nout; i++) {
-	//     REprintf("i = %d, value = %s\n", i, (bibin->value[i]).data);
-	//   }
-	//   
-	// }
+     // int nout = fields_num( bibin );
+     // if(nout > n) {
+     //   REprintf("\nbibtexdirectin_cleanref (2): nout = %d\n" , nout);
+     //   for(i = 0; i < nout; i++) {
+     //     REprintf("i = %d, value = %s\n", i, (bibin->value[i]).data);
+     //   }
+     //   
+     // }
 
 	
-	for ( i=toremove.n-1; i>=0; i-- ) {
-		fstatus = fields_remove( bibin, intlist_get( &toremove, i ) );
-		if ( fstatus!=FIELDS_OK ) { status = BIBL_ERR_MEMERR; goto out; }
-	}
+     for ( i=toremove.n-1; i>=0; i-- ) {
+	  fstatus = fields_remove( bibin, intlist_get( &toremove, i ) );
+	  if ( fstatus!=FIELDS_OK ) { status = BIBL_ERR_MEMERR; goto out; }
+     }
 
 	
 out:
 
-	intlist_free( &toremove );
+     intlist_free( &toremove );
 
 	
-	// nout = fields_num( bibin );
-	// if(nout > n) {
-	//   REprintf("\nbibtexdirectin_cleanref (end): nout = %d\n" , nout);
-	//   for(i = 0; i < nout; i++) {
-	//     REprintf("i = %d, value = %s\n", i, (bibin->value[i]).data);
-	//   }
-	//   
-	// }
+     // nout = fields_num( bibin );
+     // if(nout > n) {
+     //   REprintf("\nbibtexdirectin_cleanref (end): nout = %d\n" , nout);
+     //   for(i = 0; i < nout; i++) {
+     //     REprintf("i = %d, value = %s\n", i, (bibin->value[i]).data);
+     //   }
+     //   
+     // }
 	
-	return status;
+     return status;
 }
 
 static void
@@ -1131,7 +1129,3 @@ bibtexdirectin_typef( fields *bibin, const char *filename, int nrefs, param *p )
 
 	return get_reftype( typename, nrefs, p->progname, p->all, p->nall, refname, &is_default, REFTYPE_CHATTY );
 }
-
-
-
-
